import { useNavigate } from "react-router-dom";

export const useNavigation = () => {
    const navigate = useNavigate();

    const goToPagesAndOpenTab = (tabId: string, path: string) => {
    
        
        navigate(`${path}?tab=${tabId}`);
        
    };
    const goToTextsAndOpenCollapsible = (collapseId: string, path: string) => {
        
        navigate(`${path}?collapseId=${collapseId}`);
    };
    const goToPageWithTabAndCollapsible = ({ path, tabId, collapseId }: { path: string, tabId: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };
    const goToPageWithNestedTabs = ({ path, tabId, subTabId, collapseId }: { path: string, tabId: string, subTabId?: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (subTabId) {
            url += `&subTab=${subTabId}`;
        }
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };



    const goToPageWithTabAndScroll = ({ path, tabId, scrollToId }: { path: string, tabId: string, scrollToId: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (scrollToId) {
            url += `&scrollTo=${scrollToId}`;
        }
        navigate(url);
    };

    const goToPageAndScroll = (scrollToId: string, path: string) => {
        
        navigate(`${path}?scrollTo=${scrollToId}`);
    };

  

    const goToPlace = ({
        path,
        scrollToId,
        tabId,
        subTabId,
        collapseId,
        tabincolId
    }: { 
        path: string;
        scrollToId?: string;
        tabId?: string;
        subTabId?: string;
        collapseId?: string;
        tabincolId?: string;
    }) => {
    // Den vollständigen Pfad erstellen, indem wir den basePath und path kombinieren
    let url = `/${path.startsWith("/") ? path.slice(1) : path}`;


        
        let paramsAdded = false; 
        console.log("Found path: " + path)
        // 1. Tab-Logik (tabId und subTabId)
        if (tabId) {
            console.log("Found tabID: " + tabId)
            url += `?tab=${tabId}`;
            paramsAdded = true;
            if (subTabId) {
                console.log("Found subTabId: " + subTabId)
                url += `&subTab=${subTabId}`;
            }
        }

        // 2. Collapse-Logik (collapseId und tabincolId)
        if (collapseId) {
            console.log("Found collapseId: " + collapseId)
            if (!tabId) {
                // Wenn kein tabId gesetzt ist, fügen wir collapseId hinzu
                url += url.includes('?') ? `&collapseId=${collapseId}` : `?collapseId=${collapseId}`;
                paramsAdded = true;
            }
            if (tabincolId) {
                console.log("Found tabincolId: " + tabincolId)
                url += `&colTab=${tabincolId}`;
            }
        }

        // 3. Scroll-Logik (scrollToId)
        if (scrollToId) {
            console.log("Found scrollToId: " + scrollToId)
            paramsAdded = true;
            // Wenn bereits Parameter existieren, fügen wir & hinzu, ansonsten ?
            const separator = paramsAdded ? '&' : '?';
            url += `${separator}scrollTo=${scrollToId}`;
        }
        console.log("Final URL:", url);

        // Navigiere zur URL
        navigate(url);
    };

    
    return { goToPlace,  goToPageAndScroll, goToPagesAndOpenTab, goToPageWithTabAndScroll, goToPageWithNestedTabs, goToPageWithTabAndCollapsible, goToTextsAndOpenCollapsible };
};
